==> catalyst_builder-2.1.0.tar.gz: example/lib/src/example.container.dart <==
// ignore_for_file: prefer_relative_imports, public_member_api_docs
import 'package:catalyst_builder/catalyst_builder.dart' as _i1;
import 'chat_provider.dart' as _i5;
import 'cool_chat_provider.dart' as _i4;
import 'manually_wired_service.dart'
    as _i3;
import 'preload_service.dart' as _i8;
import 'singleton_service.dart' as _i7;
import 'transient_service.dart' as _i6;
import 'transport.dart' as _i9;
import '../../../test/third_party_dependency/lib/third_party_dependency.dart' as _i2;

class ExampleProvider extends _i1.ServiceProvider
    implements _i1.ServiceRegistry {
  ExampleProvider() {
    _knownServices.addAll(<Type, _i1.ServiceDescriptor>{
      _i2.ThirdPartyService: _i1.ServiceDescriptor(
          const _i1.Service(), () => _i2.ThirdPartyService()),
      _i3.ManuallyWiredServiceImplementation: _i1.ServiceDescriptor(
          const _i1.Service(exposeAs: _i3.ManuallyWiredService),
          () => _i3.ManuallyWiredServiceImplementation()),
      _i4.CoolChatProvider: _i1.ServiceDescriptor(
          const _i1.Service(exposeAs: _i5.ChatProvider),
          () => _i4.CoolChatProvider(
              transport:
                  _resolveOrGetParameter(_i4.CoolChatProvider, 'transport'),
              username: _resolveOrGetParameter(
                  _i4.CoolChatProvider, 'username', 'sender_username'))),
      _i6.MyTransientService: _i1.ServiceDescriptor(
          const _i1.Service(lifetime: _i1.ServiceLifetime.transient),
          () => _i6.MyTransientService()),
      _i7.MySingletonService: _i1.ServiceDescriptor(
          const _i1.Service(), () => _i7.MySingletonService()),
      _i8.PreloadService: _i1.ServiceDescriptor(
          const _i1.Service(), () => _i8.PreloadService()),
      _i9.ConsoleTransport: _i1.ServiceDescriptor(
          const _i1.Service(exposeAs: _i9.Transport),
          () => _i9.ConsoleTransport())
    });
    _exposeMap.addAll(<Type, Type>{
      _i3.ManuallyWiredService: _i3.ManuallyWiredServiceImplementation,
      _i5.ChatProvider: _i4.CoolChatProvider,
      _i9.Transport: _i9.ConsoleTransport
    });
  }

  var _booted = false;

  final _knownServices = <Type, _i1.ServiceDescriptor>{};

  final _exposeMap = <Type, Type>{};

  final _serviceInstances = <Type, dynamic>{};

  @override
  T? tryResolve<T>() {
    _ensureBoot();
    var _exposedType = _exposeMap[T];
    _exposedType ??= T;
    if (_serviceInstances.containsKey(_exposedType)) {
      return _serviceInstances[_exposedType];
    }
    var descriptor = _knownServices[_exposedType];
    if (descriptor == null) {
      return null;
    }
    var instance = descriptor.produce();
    if (descriptor.service.lifetime == _i1.ServiceLifetime.singleton) {
      _serviceInstances[_exposedType] = instance;
    }
    return instance;
  }

  @override
  T resolve<T>() {
    _ensureBoot();
    var resolved = tryResolve<T>();
    if (resolved != null) {
      return resolved;
    }
    throw _i1.ServiceNotFoundException(T);
  }

  T? _tryResolveOrGetParameter<T>(String b) {
    var resolvedService = tryResolve<T>();
    if (resolvedService != null) {
      return resolvedService;
    }
    if (parameters[b] is T) {
      return (parameters[b] as T);
    }
    return null;
  }

  T _resolveOrGetParameter<T>(Type requiredBy, String param,
      [String? parameter]) {
    var resolved = _tryResolveOrGetParameter<T>(parameter ?? param);
    if (resolved == null) {
      throw _i1.DependencyNotFoundException(
          requiredBy, param, _i1.ServiceNotFoundException(T));
    }
    return resolved;
  }

  @override
  void boot() {
    if (_booted) {
      throw const _i1.ProviderAlreadyBootedException();
    }
    _booted = true;
    resolve<_i3.ManuallyWiredService>();
    resolve<_i8.PreloadService>();
  }

  void _ensureBoot() {
    if (_booted == false) {
      throw const _i1.ProviderNotBootedException();
    }
  }

  @override
  bool has<T>([Type? type]) {
    var lookupType = type ?? T;
    return _knownServices.containsKey(_exposeMap[lookupType] ?? lookupType);
  }

  @override
  void register<T>(T Function(_i1.ServiceProvider) factory,
      [_i1.Service service = const _i1.Service()]) {
    _knownServices[T] = _i1.ServiceDescriptor(service, () => factory(this));
    if (service.exposeAs != null) {
      _exposeMap[service.exposeAs!] = T;
    }
  }
}

==> catalyst_builder-2.2.0.tar.gz: example/lib/src/example.container.dart <==
// ignore_for_file: prefer_relative_imports, public_member_api_docs
import 'package:catalyst_builder/catalyst_builder.dart' as _i1;
import 'chat_provider.dart' as _i5;
import 'cool_chat_provider.dart' as _i4;
import 'manually_wired_service.dart'
    as _i3;
import 'preload_service.dart' as _i8;
import 'singleton_service.dart' as _i7;
import 'transient_service.dart' as _i6;
import 'transport.dart' as _i9;
import '../../../test/third_party_dependency/lib/third_party_dependency.dart' as _i2;

class ExampleProvider extends _i1.ServiceProvider
    implements _i1.ServiceRegistry, _i1.EnhanceableProvider {
  ExampleProvider() {
    _knownServices.addAll(<Type, _i1.ServiceDescriptor>{
      _i2.ThirdPartyService: _i1.ServiceDescriptor(
          const _i1.Service(), () => _i2.ThirdPartyService()),
      _i3.ManuallyWiredServiceImplementation: _i1.ServiceDescriptor(
          const _i1.Service(exposeAs: _i3.ManuallyWiredService),
          () => _i3.ManuallyWiredServiceImplementation()),
      _i4.CoolChatProvider: _i1.ServiceDescriptor(
          const _i1.Service(exposeAs: _i5.ChatProvider),
          () => _i4.CoolChatProvider(
              transport:
                  _resolveOrGetParameter(_i4.CoolChatProvider, 'transport'),
              username: _resolveOrGetParameter(
                  _i4.CoolChatProvider, 'username', 'sender_username'))),
      _i6.MyTransientService: _i1.ServiceDescriptor(
          const _i1.Service(lifetime: _i1.ServiceLifetime.transient),
          () => _i6.MyTransientService()),
      _i7.MySingletonService: _i1.ServiceDescriptor(
          const _i1.Service(), () => _i7.MySingletonService()),
      _i8.PreloadService: _i1.ServiceDescriptor(
          const _i1.Service(), () => _i8.PreloadService()),
      _i9.ConsoleTransport: _i1.ServiceDescriptor(
          const _i1.Service(exposeAs: _i9.Transport),
          () => _i9.ConsoleTransport())
    });
    _exposeMap.addAll(<Type, Type>{
      _i3.ManuallyWiredService: _i3.ManuallyWiredServiceImplementation,
      _i5.ChatProvider: _i4.CoolChatProvider,
      _i9.Transport: _i9.ConsoleTransport
    });
  }

  var _booted = false;

  final _knownServices = <Type, _i1.ServiceDescriptor>{};

  final _exposeMap = <Type, Type>{};

  final _serviceInstances = <Type, dynamic>{};

  @override
  T? tryResolve<T>() {
    _ensureBoot();
    var _exposedType = _exposeMap[T];
    _exposedType ??= T;
    if (_serviceInstances.containsKey(_exposedType)) {
      return _serviceInstances[_exposedType];
    }
    var descriptor = _knownServices[_exposedType];
    if (descriptor == null) {
      return null;
    }
    var instance = descriptor.produce();
    if (descriptor.service.lifetime == _i1.ServiceLifetime.singleton) {
      _serviceInstances[_exposedType] = instance;
    }
    return instance;
  }

  @override
  T resolve<T>() {
    _ensureBoot();
    var resolved = tryResolve<T>();
    if (resolved != null) {
      return resolved;
    }
    throw _i1.ServiceNotFoundException(T);
  }

  T? _tryResolveOrGetParameter<T>(String b) {
    var resolvedService = tryResolve<T>();
    if (resolvedService != null) {
      return resolvedService;
    }
    if (parameters[b] is T) {
      return (parameters[b] as T);
    }
    return null;
  }

  T _resolveOrGetParameter<T>(Type requiredBy, String param,
      [String? parameter]) {
    var resolved = _tryResolveOrGetParameter<T>(parameter ?? param);
    if (resolved == null) {
      throw _i1.DependencyNotFoundException(
          requiredBy, param, _i1.ServiceNotFoundException(T));
    }
    return resolved;
  }

  @override
  void boot() {
    if (_booted) {
      throw const _i1.ProviderAlreadyBootedException();
    }
    _booted = true;
    resolve<_i3.ManuallyWiredService>();
    resolve<_i8.PreloadService>();
  }

  void _ensureBoot() {
    if (_booted == false) {
      throw const _i1.ProviderNotBootedException();
    }
  }

  @override
  bool has<T>([Type? type]) {
    var lookupType = type ?? T;
    return _knownServices.containsKey(_exposeMap[lookupType] ?? lookupType);
  }

  @override
  void register<T>(T Function(_i1.ServiceProvider) factory,
      [_i1.Service service = const _i1.Service()]) {
    _knownServices[T] = _i1.ServiceDescriptor(service, () => factory(this));
    if (service.exposeAs != null) {
      _exposeMap[service.exposeAs!] = T;
    }
  }

  @override
  _i1.ServiceProvider enhance(
      {List<_i1.LazyServiceDescriptor> services =
          const <_i1.LazyServiceDescriptor>[],
      Map<String, dynamic> parameters = const <String, dynamic>{}}) {
    _ensureBoot();
    var enhanced = ExampleProvider();
    enhanced._serviceInstances.addAll(_serviceInstances);
    for (var service in services) {
      enhanced.register(service.factory, service.service);
    }
    enhanced.parameters.addAll(parameters);
    enhanced._booted = true;
    return enhanced;
  }
}
